@@ -1,5 +1,5 @@
 package Statocles::Command::bundle;
-our $VERSION = '0.093';
+our $VERSION = '0.094';
 # ABSTRACT: Copy a default theme to this site to make changes
 
 use Statocles::Base 'Command';
@@ -45,7 +45,7 @@ sub bundle_theme {
         my $dest = $theme_dest->child( $path );
         # Don't overwrite site-customized hooks
         next if ( $abs_path->stat->size == 0 && $dest->exists );
-        site->log->debug( sprintf 'Copying theme file "%s" to "%s"', $path, $dest );
+        Statocles->log( debug => sprintf 'Copying theme file "%s" to "%s"', $path, $dest );
         $dest->remove if $dest->exists;
         $dest->parent->mkpath;
         $abs_path->copy( $dest );
@@ -66,7 +66,7 @@ Statocles::Command::bundle - Copy a default theme to this site to make changes
 
 =head1 VERSION
 
-version 0.093
+version 0.094
 
 =head1 AUTHOR
 
