@@ -1,5 +1,5 @@
 package Statocles::Store;
-our $VERSION = '0.093';
+our $VERSION = '0.094';
 # ABSTRACT: The source for data documents and files
 
 use Statocles::Base 'Class';
@@ -69,7 +69,7 @@ has _check_exists => (
     default => sub {
         my ( $self ) = @_;
         if ( !$self->path->exists ) {
-            site->log->warn( sprintf qq{Store path "%s" does not exist}, $self->path );
+            Statocles->log( warn => sprintf qq{Store path "%s" does not exist}, $self->path );
         }
         return 1;
     },
@@ -145,28 +145,28 @@ sub has_file {
 
 sub write_file {
     my ( $self, $path, $content ) = @_;
-    site->log->debug( "Write file: " . $path );
-    my $full_path = $self->path->child( $path );
+    Statocles->log( debug => "Write file: " . $path );
+    my $full_path = $self->path->child( $path )->touchpath;
 
     #; say "Writing full path: " . $full_path;
 
     if ( ref $content eq 'GLOB' ) {
-        my $fh = $full_path->touchpath->openw_raw;
+        my $fh = $full_path->openw_raw;
         while ( my $line = <$content> ) {
             $fh->print( $line );
         }
     }
     elsif ( blessed $content && $content->isa( 'Path::Tiny' ) ) {
-        $content->copy( $full_path->touchpath );
+        $content->copy( $full_path );
     }
     elsif ( blessed $content && $content->isa( 'Statocles::Document' ) ) {
-        $full_path->touchpath->spew_utf8( $content->deparse_content );
+        $full_path->spew_utf8( $content->deparse_content );
     }
     elsif ( blessed $content && $content->isa( 'Statocles::File' ) ) {
-        $content->path->copy( $full_path->touchpath );
+        $content->path->copy( $full_path );
     }
     else {
-        $full_path->touchpath->spew_utf8( $content );
+        $full_path->spew_utf8( $content );
     }
 
     return;
@@ -284,7 +284,7 @@ Statocles::Store - The source for data documents and files
 
 =head1 VERSION
 
-version 0.093
+version 0.094
 
 =head1 DESCRIPTION
 
